tslumen.report package
======================

.. automodule:: tslumen.report
   :members:
   :undoc-members:
   :show-inheritance:


.. toctree::

   tslumen.report.html
   tslumen.report.dashboard


tslumen.report.base module
--------------------------

.. automodule:: tslumen.report.base
   :members:
   :undoc-members:
   :show-inheritance:
